==> mysql-8.0_8.0.42.orig.tar.gz: mysql-8.0.42/sql/changestreams/apply/constants.h <==
/*
   Copyright (c) 2021, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef CHANGE_STREAM_APPLY_CONSTANTS_H_
#define CHANGE_STREAM_APPLY_CONSTANTS_H_

/* masks for start/stop operations on io and sql slave threads */
static constexpr unsigned long SLAVE_IO = 1;
static constexpr unsigned long SLAVE_SQL = 2;
// We also have SLAVE_FORCE_ALL 4
static constexpr unsigned long SLAVE_MONITOR = 8;

#endif /* CHANGE_STREAM_APPLY_CONSTANTS_H_ */

==> mysql-8.4.8.tar.gz: mysql-8.4.8/sql/changestreams/apply/constants.h <==
/*
   Copyright (c) 2021, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef CHANGE_STREAM_APPLY_CONSTANTS_H_
#define CHANGE_STREAM_APPLY_CONSTANTS_H_

/* masks for start/stop operations on io and sql threads */
static constexpr unsigned long REPLICA_IO = 1;
static constexpr unsigned long REPLICA_SQL = 2;
// We also have SLAVE_FORCE_ALL 4
static constexpr unsigned long SLAVE_MONITOR = 8;

#endif /* CHANGE_STREAM_APPLY_CONSTANTS_H_ */
